==> 0.0.6.tar.gz: android/src/main/java/mn/grapecity/payment_pos/payment_pos/PaymentPosPlugin.java <==
package mn.grapecity.payment_pos.payment_pos;

import android.app.Activity;
import android.content.Intent;

import androidx.annotation.NonNull;

//import org.json.JSONObject;

import io.flutter.Log;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * PaymentPosPlugin
 */
public class PaymentPosPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware, PluginRegistry.ActivityResultListener {

    private static Result methodResult;
    private Activity activity;
    private MethodChannel channel;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "payment_pos");
        channel.setMethodCallHandler(this);
    }

    @Override
    public void onAttachedToActivity(ActivityPluginBinding activityPluginBinding) {
        activity = activityPluginBinding.getActivity();

        activityPluginBinding.addActivityResultListener(this);
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {
    }

    @Override
    public void onReattachedToActivityForConfigChanges(ActivityPluginBinding activityPluginBinding) {
    }

    @Override
    public void onDetachedFromActivity() {
    }

    public static void registerWith(Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "payment_pos");
        channel.setMethodCallHandler(new PaymentPosPlugin());
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        if (call.method.equals("pay")) {
            methodResult = result;

            String amount = call.argument("amount");

            Intent intent = activity.getPackageManager().getLaunchIntentForPackage("mn.mid.edc");
            if (intent != null) {
                intent.setAction("mn.mid.edc.ACTION_AMOUNT");
                intent.setFlags(0);
                intent.putExtra("amount", amount);
                intent.putExtra("type", "activity");
                activity.startActivityForResult(intent, 100);
            }
        } else if (call.method.equals("printEbarimt")) {
            methodResult = result;

            Intent intent = activity.getPackageManager().getLaunchIntentForPackage("mn.mid.edc");
            if (intent != null) {
                intent.setAction("mn.mid.edc.ACTION_AMOUNT");
                intent.setFlags(0);
                intent.putExtra("printParking", call.argument("jsonData"));
                intent.putExtra("type", "activity");
                activity.startActivityForResult(intent, 101);
            }
        }
    }

    public static void hasResponse(String code, String description, String rrn) {
        Log.d("hasResponse:", code + ";" + description + ";" + rrn);
        methodResult.success(code + ";" + description + ";" + rrn);
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }

    @Override
    public boolean onActivityResult(int requestCode, int resultCode, Intent data) {
        Log.d("onActivityResult:", requestCode + ";" + resultCode + ";" + data);
        if (requestCode == 100) {
            String code = data.getStringExtra("code");
            String description = data.getStringExtra("description");
            String rrn = data.getStringExtra("rrn");

            hasResponse(code, description, rrn);
        } else if (requestCode == 101) {
            String code = data.getStringExtra("code");
            String description = data.getStringExtra("description");
            String rrn = data.getStringExtra("rrn");

            hasResponse(code, description, rrn);
        }

        return true;
    }
}

==> 0.0.9.tar.gz: android/src/main/java/mn/grapecity/payment_pos/payment_pos/PaymentPosPlugin.java <==
package mn.grapecity.payment_pos.payment_pos;

import android.app.Activity;
import android.content.Intent;

import androidx.annotation.NonNull;

//import org.json.JSONObject;

import io.flutter.Log;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * PaymentPosPlugin
 */
public class PaymentPosPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware, PluginRegistry.ActivityResultListener {

    private static Result methodResult;
    private Activity activity;
    private MethodChannel channel;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "payment_pos");
        channel.setMethodCallHandler(this);
    }

    @Override
    public void onAttachedToActivity(ActivityPluginBinding activityPluginBinding) {
        activity = activityPluginBinding.getActivity();

        activityPluginBinding.addActivityResultListener(this);
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {
    }

    @Override
    public void onReattachedToActivityForConfigChanges(ActivityPluginBinding activityPluginBinding) {
    }

    @Override
    public void onDetachedFromActivity() {
    }

    public static void registerWith(Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "payment_pos");
        channel.setMethodCallHandler(new PaymentPosPlugin());
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        if (call.method.equals("pay")) {
            methodResult = result;

            String amount = call.argument("amount");

            Intent intent = activity.getPackageManager().getLaunchIntentForPackage("mn.mid.edc");
            if (intent != null) {
                intent.setAction("mn.mid.edc.ACTION_AMOUNT");
                intent.setFlags(0);
                intent.putExtra("amount", amount);
                intent.putExtra("type", "activity");
                activity.startActivityForResult(intent, 100);
            }
        } else if (call.method.equals("printEbarimt")) {
            methodResult = result;

            String json = call.argument("jsonData");

            Intent intent = activity.getPackageManager().getLaunchIntentForPackage("mn.mid.edc");
            if (intent != null) {
                intent.setAction("mn.mid.edc.ACTION_AMOUNT");
                intent.setFlags(0);
                intent.putExtra("printParking", json);
                intent.putExtra("type", "activity");
                activity.startActivityForResult(intent, 101);
            }
        }
    }

    public static void hasResponse(String code, String description, String rrn) {
        Log.d("hasResponse:", code + ";" + description + ";" + rrn);
        methodResult.success(code + ";" + description + ";" + rrn);
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }

    @Override
    public boolean onActivityResult(int requestCode, int resultCode, Intent data) {
        Log.d("onActivityResult:", requestCode + ";" + resultCode + ";" + data);
        if (requestCode == 100) {
            String code = data.getStringExtra("code");
            String description = data.getStringExtra("description");
            String rrn = data.getStringExtra("rrn");

            hasResponse(code, description, rrn);
        }
//        else if (requestCode == 101) {
//            String code = data.getStringExtra("code");
//            String description = data.getStringExtra("description");
//            String rrn = data.getStringExtra("rrn");
//
//            hasResponse(code, description, rrn);
//        }

        return true;
    }
}
